========================
brain-indexer Python API
========================
.. automodule:: brain_indexer


High-Level Index API
====================

Open Index
----------
.. autofunction:: open_index

SphereIndex
-----------
.. autoclass:: SphereIndex
   :members:
   :inherited-members:

MorphIndex
----------
.. autoclass:: MorphIndex
   :members:
   :inherited-members:

SynapseIndex
------------
.. autoclass:: SynapseIndex
   :members:
   :inherited-members:

MorphMultiIndex
---------------
.. autoclass:: MorphMultiIndex
   :members:
   :inherited-members:

SynapseMultiIndex
-----------------
.. autoclass:: SynapseMultiIndex
   :members:
   :inherited-members:


High-Level Builder API
======================

MorphIndexBuilder
-----------------
.. autoclass:: MorphIndexBuilder
   :members:
   :inherited-members:

SynapseIndexBuilder
-------------------
.. autoclass:: SynapseIndexBuilder
   :members:
   :inherited-members:

MorphMultiIndexBuilder
----------------------
.. autoclass:: MorphMultiIndexBuilder
   :members:
   :inherited-members:

SynapseMultiIndexBuilder
------------------------
.. autoclass:: SynapseMultiIndexBuilder
   :members:
   :inherited-members:


